@@ -91,14 +91,16 @@ from beartype._decor._error._proposal._errorpep586 import (
     get_cause_or_none_literal)
 from beartype._decor._error._proposal._errorpep593 import (
     get_cause_or_none_annotated)
-from beartype._util.hint.data.pep.utilhintdatapep import (
-    HINT_PEP_SIGNS_SEQUENCE_STANDARD,
-    HINT_PEP_SIGNS_TUPLE,
-    HINT_PEP_SIGNS_TYPE_ORIGIN_STDLIB,
+from beartype._util.data.hint.pep.datapep import (
+    HINT_SIGNS_SEQUENCE_STANDARD,
+    HINT_SIGNS_TUPLE,
+    HINT_SIGNS_TYPE_ORIGIN_STDLIB,
 )
-from beartype._util.hint.data.pep.proposal.utilhintdatapep484 import (
-    HINT_PEP484_TYPE_FORWARDREF,
-    HINT_PEP484_SIGNS_UNION,
+from beartype._util.data.hint.pep.proposal.datapep484 import (
+    HINT_PEP484_SIGNS_UNION)
+from beartype._util.data.hint.pep.sign.datapepsigns import (
+    HintSignForwardRef,
+    HintSignGeneric,
 )
 from beartype._util.hint.utilhinttest import die_unless_hint
 from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_9
@@ -109,7 +111,7 @@ from beartype._util.text.utiltextlabel import (
 from beartype._util.text.utiltextmunge import suffix_unless_suffixed
 from beartype._util.text.utiltextrepr import represent_object
 from collections.abc import Callable
-from typing import Generic, Optional, Type
+from typing import NoReturn, Optional, Type
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
@@ -280,9 +282,13 @@ def raise_pep_call_exception(
     # PEP-compliant type hint annotating this parameter or return value.
     hint = func.__annotations__[pith_name]
 
-    # If type hint is *NOT* a supported type hint, raise an exception.
-    die_unless_hint(hint=hint, hint_label=f'{pith_label} type hint')
-    # Else, this type hint is supported.
+    # If this is *NOT* the PEP 484-compliant "typing.NoReturn" type hint
+    # permitted *ONLY* as a return annotation, this is a standard type hint
+    # generally supported by both parameters and return values. In this case...
+    if hint is not NoReturn:
+        # If type hint is *NOT* a supported type hint, raise an exception.
+        die_unless_hint(hint=hint, hint_label=f'{pith_label} type hint')
+        # Else, this type hint is supported.
 
     # Human-readable string describing the failure of this pith to satisfy this
     # hint if this pith fails to satisfy this hint *OR* "None" otherwise (i.e.,
@@ -335,17 +341,17 @@ def _init() -> None:
     # Map each originative "typing" attribute to the appropriate getter
     # *BEFORE* mapping any other attributes. This is merely a generalized
     # fallback subsequently replaced by attribute-specific getters.
-    for pep_sign_type_origin in HINT_PEP_SIGNS_TYPE_ORIGIN_STDLIB:
+    for pep_sign_type_origin in HINT_SIGNS_TYPE_ORIGIN_STDLIB:
         PEP_HINT_SIGN_TO_GET_CAUSE_FUNC[pep_sign_type_origin] = (
             get_cause_or_none_type_origin)
 
     # Map each standard sequence "typing" attribute to the appropriate getter.
-    for pep_sign_sequence_standard in HINT_PEP_SIGNS_SEQUENCE_STANDARD:
+    for pep_sign_sequence_standard in HINT_SIGNS_SEQUENCE_STANDARD:
         PEP_HINT_SIGN_TO_GET_CAUSE_FUNC[pep_sign_sequence_standard] = (
             get_cause_or_none_sequence_standard)
 
     # Map each tuple "typing" attribute to the appropriate getter.
-    for pep_sign_tuple in HINT_PEP_SIGNS_TUPLE:
+    for pep_sign_tuple in HINT_SIGNS_TUPLE:
         PEP_HINT_SIGN_TO_GET_CAUSE_FUNC[pep_sign_tuple] = (
             get_cause_or_none_tuple)
 
@@ -357,8 +363,8 @@ def _init() -> None:
     # Map each "typing" attribute validated by a unique getter specific to that
     # attribute to that getter.
     PEP_HINT_SIGN_TO_GET_CAUSE_FUNC.update({
-        HINT_PEP484_TYPE_FORWARDREF: get_cause_or_none_forwardref,
-        Generic: get_cause_or_none_generic,
+        HintSignForwardRef: get_cause_or_none_forwardref,
+        HintSignGeneric: get_cause_or_none_generic,
     })
 
     # If the active Python interpreter targets at least Python >= 3.9...
