@@ -4,30 +4,32 @@
 # See "LICENSE" for further details.
 
 '''
-**Beartype PEP-compliant type hint getter utilities** (i.e., callables querying
-arbitrary objects for attributes specific to PEP-compliant type hints).
+Project-wide **PEP-compliant type hint getter utilities** (i.e., callables
+querying arbitrary objects for attributes specific to PEP-compliant type
+hints).
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                           }....................
 import typing
+from beartype.meta import URL_ISSUES
 from beartype.roar import (
     BeartypeDecorHintPepException,
     BeartypeDecorHintPepSignException,
 )
 from beartype._cave._cavefast import NoneType
 from beartype._util.cache.utilcachecall import callable_cached
-from beartype._util.hint.data.pep.utilhintdatapep import (
-    HINT_PEP_SIGNS_TYPE,
-    HINT_PEP_SIGNS_TYPE_ORIGIN_STDLIB,
+from beartype._util.data.hint.pep.datapep import (
+    HINT_PEP_ATTRS_ISINSTANCEABLE,
+    HINT_PEP_MODULE_NAMES,
+    HINT_SIGNS_TYPE_ORIGIN_STDLIB,
 )
-from beartype._util.hint.data.pep.proposal.utilhintdatapep484 import (
-    HINT_PEP484_TYPE_FORWARDREF)
-from beartype._util.py.utilpyversion import (
-    IS_PYTHON_3_6,
-    IS_PYTHON_AT_LEAST_3_7,
-    IS_PYTHON_AT_LEAST_3_9,
+from beartype._util.data.hint.pep.sign.datapepsigns import (
+    HintSignForwardRef,
+    HintSignGeneric,
+    HintSignNewType,
+    HintSignTypeVar,
 )
 from beartype._util.hint.pep.proposal.utilhintpep484 import (
     get_hint_pep484_generic_bases_unerased,
@@ -39,7 +41,13 @@ from beartype._util.hint.pep.proposal.utilhintpep585 import (
     is_hint_pep585_builtin,
     is_hint_pep585_generic,
 )
-from typing import Any, Generic, NewType, Optional, Tuple, TypeVar
+from beartype._util.py.utilpymodule import import_module
+from beartype._util.py.utilpyversion import (
+    IS_PYTHON_AT_LEAST_3_9,
+    IS_PYTHON_AT_LEAST_3_7,
+    IS_PYTHON_3_6,
+)
+from typing import Any, Optional, Tuple
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
@@ -286,10 +294,22 @@ get_hint_pep_typevars.__doc__ = '''
     '''
 
 # ....................{ GETTERS ~ sign                    }....................
+#FIXME: Refactor as follows *AFTER* finalizing our sign refactoring:
+# from beartype._util.data.hint.pep.sign.datapepsigncls import HintSignOrType
+# @callable_cached
+# def get_hint_pep_sign_or_cls(hint: Any) -> HintSignOrType:
+#FIXME: Refactor all functions throughout the codebase that accept or return
+#signs to be annotated ideally by "HintSign" (or, if necessary, by
+#"HintSignOrType"). These include:
+#* is_hint_pep_sign_supported().
+#FIXME: Test that our "testing_extensions.Annotated" support actually works.
+#FIXME: Revise us up the docstring, most of which is now obsolete.
+#FIXME: Validate that the value of the "pep_sign" parameter passed to the
+#PepHintMetadata.__init__() constructor satisfies "HintSignOrType".
 @callable_cached
 def get_hint_pep_sign(hint: Any) -> object:
     '''
-    **Sign** (i.e., arbitrary object) uniquely identifying the passed
+    **Sign** (i.e., :class:`HintSign` instance) uniquely identifying the passed
     PEP-compliant type hint if this hint is PEP-compliant *or* raise an
     exception otherwise (i.e., if this hint is *not* PEP-compliant).
 
@@ -302,35 +322,36 @@ def get_hint_pep_sign(hint: Any) -> object:
     these attributes are sufficiently unique to enable callers to distinguish
     between numerous broad categories of :mod:`typing` behaviour and logic.
 
-    Specifically, this function returns either:
+    Specifically, if this hint is:
 
-    * If this hint is a `PEP 585`_-compliant **builtin** (e.g., C-based type
+    * A :pep:`585`-compliant **builtin** (e.g., C-based type
       hint instantiated by subscripting either a concrete builtin container
       class like :class:`list` or :class:`tuple` *or* an abstract base class
       (ABC) declared by the :mod:`collections.abc` submodule like
       :class:`collections.abc.Iterable` or :class:`collections.abc.Sequence`),
-      :class:`beartype.cave.HintGenericSubscriptedType`.
-    * If this hint is a **generic** (i.e., subclasses of the
-      :class:`typing.Generic` abstract base class (ABC)),
-      :class:`typing.Generic`. Note this includes `PEP 544`-compliant
-      **protocols** (i.e., subclasses of the :class:`typing.Protocol` ABC),
-      which implicitly subclass the :class:`typing.Generic` ABC as well.
-    * If this hint is any other class declared by either the :mod:`typing`
-      module (e.g., :class:`typing.TypeVar`) *or* the :mod:`beartype.cave`
-      submodule (e.g., :class:`beartype.cave.HintGenericSubscriptedType`), that class.
-    * If this hint is a **forward reference** (i.e., string or instance of the
-      concrete :class:`typing.ForwardRef` class), :class:`typing.ForwardRef`.
-    * If this hint is a **type variable** (i.e., instance of the concrete
-      :class:`typing.TypeVar` class), :class:`typing.TypeVar`.
-    * Else, the unsubscripted :mod:`typing` attribute dynamically retrieved by
-      inspecting this hint's **object representation** (i.e., the
-      non-human-readable string returned by the :func:`repr` builtin).
+      this function returns ::class:`beartype.cave.HintGenericSubscriptedType`.
+    * A **generic** (i.e., subclass of the :class:`typing.Generic` abstract
+      base class (ABC)), this function returns :class:`HintSignGeneric`. Note
+      this includes :pep:`544`-compliant **protocols** (i.e., subclasses of the
+      :class:`typing.Protocol` ABC), which implicitly subclass the
+      :class:`typing.Generic` ABC as well.
+    * A **forward reference** (i.e., string or instance of the concrete
+      :class:`typing.ForwardRef` class), this function returns
+      :class:`HintSignTypeVar`.
+    * A **type variable** (i.e., instance of the concrete
+      :class:`typing.TypeVar` class), this function returns
+      :class:`HintSignTypeVar`.
+    * Any other class, this function returns that class as is.
+    * Anything else, this function returns the unsubscripted :mod:`typing`
+      attribute dynamically retrieved by inspecting this hint's **object
+      representation** (i.e., the non-human-readable string returned by the
+      :func:`repr` builtin).
 
     This getter function is memoized for efficiency.
 
     Motivation
     ----------
-    Both `PEP 484`_ and the :mod:`typing` module implementing `PEP 484`_ are
+    Both :pep:`484` and the :mod:`typing` module implementing :pep:`484` are
     functionally deficient with respect to their public APIs. Neither provide
     external callers any means of deciding the categories of arbitrary
     PEP-compliant type hints. For example, there exists no general-purpose
@@ -374,18 +395,13 @@ def get_hint_pep_sign(hint: Any) -> object:
         typing.Union
         >>> T = typing.TypeVar('T')
         >>> get_hint_pep_sign(T)
-        typing.TypeVar
+        HintSignTypeVar
         >>> class Genericity(typing.Generic[T]): pass
         >>> get_hint_pep_sign(Genericity)
-        typing.Generic
+        HintSignGeneric
         >>> class Duplicity(typing.Iterable[T], typing.Container[T]): pass
         >>> get_hint_pep_sign(Duplicity)
         typing.Iterable
-
-    .. _PEP 484:
-       https://www.python.org/dev/peps/pep-0484
-    .. _PEP 585:
-       https://www.python.org/dev/peps/pep-0585
     '''
 
     # Avoid circular import dependencies.
@@ -393,6 +409,7 @@ def get_hint_pep_sign(hint: Any) -> object:
     from beartype._util.hint.pep.utilhintpeptest import (
         die_unless_hint_pep,
         is_hint_pep_generic,
+        is_hint_pep_subscripted,
         is_hint_pep_typevar,
     )
 
@@ -416,13 +433,13 @@ def get_hint_pep_sign(hint: Any) -> object:
     #
     # If this hint is a PEP-compliant generic (i.e., class
     # superficially subclassing at least one non-class PEP-compliant object),
-    # return the "typing.Generic" abstract base class (ABC) generically -- get
-    # it? -- identifying PEP-compliant generics. Note that:
+    # return the "SignGeneric" object generically -- get it? -- identifying
+    # PEP-compliant generics. Note that:
     #
     # * Generics *CANNOT* be detected by the general-purpose logic performed
-    #   below, as this ABC does *NOT* define a __repr__() dunder method
-    #   returning a string prefixed by the "typing." substring. Ergo, we
-    #   necessarily detect generics with an explicit test instead.
+    #   below, as the "typing.Generic" ABC does *NOT* define a __repr__()
+    #   dunder method returning a string prefixed by the "typing." substring.
+    #   Ergo, we necessarily detect generics with an explicit test instead.
     # * *ALL* PEP 484-compliant generics and PEP 544-compliant protocols are
     #   guaranteed by the "typing" module to subclass this ABC regardless of
     #   whether those generics originally did so explicitly. How? By type
@@ -441,7 +458,7 @@ def get_hint_pep_sign(hint: Any) -> object:
     # non-ideal, the failure of PEP 585-compliant generics to subclass a common
     # superclass leaves us with little alternative.
     elif is_hint_pep_generic(hint):
-        return Generic
+        return HintSignGeneric
     # Else, this hint is *NOT* a generic.
     #
     # If this hint is a PEP 585-compliant type hint, return the origin type
@@ -454,13 +471,8 @@ def get_hint_pep_sign(hint: Any) -> object:
         return hint.__origin__
     # Else, this hint is *NOT* a PEP 585-compliant type hint.
     #
-    # If this hint is...
-    elif (
-        # A class...
-        isinstance(hint, type) and
-        # *NOT* subscripted by one or more child hints or type variables...
-        not (get_hint_pep_args(hint) or get_hint_pep_typevars(hint))
-    # Then this class is a standard class. In this case...
+    # If this hint is an unsubscripted class doubling as an explicitly
+    # PEP-compliant type hint...
     #
     # Note that this is principally useful under Python 3.6, which
     # idiosyncratically defines subscriptions of "typing" objects as classes:
@@ -471,16 +483,20 @@ def get_hint_pep_sign(hint: Any) -> object:
     # While we *COULD* technically fence this conditional behind a Python 3.6
     # check, doing so would render this getter less robust against unwarranted
     # stdlib changes. Ergo, we preserve this as is for forward-proofing.
-    ):
+    elif isinstance(hint, type) and not is_hint_pep_subscripted(hint):
         # If this class is *NOT* explicitly allowed as a sign, raise an
         # exception.
-        if hint not in HINT_PEP_SIGNS_TYPE:
+        if hint not in HINT_PEP_ATTRS_ISINSTANCEABLE:
             raise BeartypeDecorHintPepSignException(
-                f'Unsubscripted non-generic class {repr(hint)} invalid as '
-                f'sign (i.e., not in {repr(HINT_PEP_SIGNS_TYPE)}).'
+                f'Unsubscripted non-generic typing class {repr(hint)} invalid '
+                f'as type hint '
+                f'(i.e., not in {repr(HINT_PEP_ATTRS_ISINSTANCEABLE)}).'
             )
         # Else, this class is explicitly allowed as a sign.
 
+        #FIXME: Actually... we need to map this to an actual "HintSign" now.
+        #Honestly, can't we just remove all of this and defer to
+        #"hint.__qualname__" below to automate this mapping?
         # Return this class as is.
         return hint
     # Else, this hint is either not a class *OR* or class subscripted by one or
@@ -499,7 +515,7 @@ def get_hint_pep_sign(hint: Any) -> object:
     #     >>> repr(t.ForwardRef('str'))
     #     "ForwardRef('str')"
     elif is_hint_forwardref(hint):
-        return HINT_PEP484_TYPE_FORWARDREF
+        return HintSignForwardRef
     # If this hint is a PEP 484-compliant new type, return the closure factory
     # function responsible for creating these types.
     #
@@ -512,7 +528,7 @@ def get_hint_pep_sign(hint: Any) -> object:
     #     >>> repr(t.NewType('FakeStr', str))
     #     '<function NewType.<locals>.new_type at 0x7fca39388050>'
     elif is_hint_pep484_newtype(hint):
-        return NewType
+        return HintSignNewType
     # If this hint is a type variable, return the class of all type variables.
     #
     # Note that type variables *CANNOT* be detected by the general-purpose
@@ -529,7 +545,7 @@ def get_hint_pep_sign(hint: Any) -> object:
     # this API was designed by incorrigible monkeys who profoundly hate the
     # Python language. This is why we can't have sane things.
     elif is_hint_pep_typevar(hint):
-        return TypeVar
+        return HintSignTypeVar
     #FIXME: Drop this like hot lead after dropping Python 3.6 support.
     # If the active Python interpreter targets Python 3.6 *AND* this hint is a
     # poorly designed Python 3.6-specific "type alias", this hint is a
@@ -555,38 +571,33 @@ def get_hint_pep_sign(hint: Any) -> object:
     # Ergo, this string is effectively the *ONLY* sane means of deciding which
     # broad category of behaviour an arbitrary PEP 484-compliant type hint
     # conforms to.
-    sign_name = repr(hint)
+    hint_name = repr(hint)
 
-    # If this representation is *NOT* prefixed by "typing,", this hint does
-    # *NOT* originate from the "typing" module and is thus *NOT* PEP-compliant.
-    # But by the validation above, this hint is PEP-compliant. Since this
-    # invokes a world-shattering paradox, raise an exception
-    if not sign_name.startswith('typing.'):
+    # Split this representation on the first "." into:
+    # * "hint_module_name", the unqualified name of the module declaring this
+    #   hint.
+    # * "sign_name", the unqualified name of the possibly subscripted attribute
+    #   of this module defining this hint.
+    hint_module_name, _, hint_module_attr_name = hint_name.partition('.')
+
+    # If the name of this module is *NOT* that of a well-known hinting module
+    # (i.e., module declaring attributes usable for creating PEP-compliant
+    # type hints accepted by both static and runtime type checkers), this hint
+    # does *NOT* originate from such a module and is thus by definition *NOT*
+    # PEP-compliant. But by the validation above, this hint is PEP-compliant.
+    # Since this invokes a world-shattering paradox, raise an exception.
+    if hint_module_name not in HINT_PEP_MODULE_NAMES:
         raise BeartypeDecorHintPepSignException(
-            f'PEP 484 type hint {repr(hint)} '
-            f'representation "{sign_name}" not prefixed by "typing.".'
+            f'Type hint {repr(hint)} representation "{hint_name}" not '
+            f'prefixed by "typing." or "typing_extensions.".'
         )
 
-    # Strip the now-harmful "typing." prefix from this representation.
-    # Preserving this prefix would raise an "AttributeError" exception from
-    # the subsequent call to the getattr() builtin.
-    sign_name = sign_name[7:]  # hardcode us up the bomb
-
-    # 0-based index of the first "[" delimiter in this representation if
-    # any *OR* -1 otherwise.
-    sign_name_bracket_index = sign_name.find('[')
-
-    # If this representation contains such a delimiter, this is a subscripted
-    # type hint. In this case, reduce this representation to its unsubscripted
-    # form by truncating the suffixing parametrization from this representation
-    # (e.g., from "typing.Union[str, typing.Sequence[int]]" to merely
-    # "typing.Union").
-    #
-    # Note that this is the common case and thus explicitly tested first.
-    if sign_name_bracket_index > 0:
-        sign_name = sign_name[:sign_name_bracket_index]
-    # Else, this representation contains no such delimiter and is thus already
-    # unsubscripted. In this case, preserve this representation as is.
+    # Unqualified name of this unsubscripted attribute. Specifically, if the
+    # unqualified name of this possibly subscripted attribute was:
+    # * Already unsubscripted (e.g., "List"), this is the same name unmodified.
+    # * Subscripted (e.g., "List[str]"), this is the prefix of that name
+    #   preceding the first "[" delimiter in that name.
+    sign_name, _, _ = hint_module_attr_name.partition('[')
 
     # If this name erroneously refers to a non-existing "typing" attribute,
     # rewrite this name to refer to the actual existing "typing" attribute
@@ -595,18 +606,54 @@ def get_hint_pep_sign(hint: Any) -> object:
     # "typing.ContextManager" attribute).
     sign_name = _HINT_PEP_TYPING_NAME_BAD_TO_GOOD.get(sign_name, sign_name)
 
-    # "typing" attribute with this name if any *OR* "None" otherwise.
-    sign = getattr(typing, sign_name, None)
+    # Module declaring this unsubscripted attribute if importable *OR* raise
+    # an exception otherwise (i.e., if this module is unimportable).
+    hint_module = import_module(
+        module_name=hint_module_name,
+        exception_cls=BeartypeDecorHintPepSignException,
+    )
 
-    # If this "typing" attribute does *NOT* exist...
+    # Unsubscripted attribute with this name declared by this module if any
+    # *OR* "None" otherwise.
+    sign = getattr(hint_module, sign_name, None)
+
+    # If this module declares *NO* such attribute, raise an exception.
     if sign is None:
         raise BeartypeDecorHintPepSignException(
-            f'PEP 484 type hint {repr(hint)} '
-            f'attribute "typing.{sign_name}" not found.'
+            f'Type hint {repr(hint)} attribute "typing.{sign_name}" not found.'
         )
-    # Else, this "typing" attribute exists.
+    # Else, this module declares this attribute.
 
-    # Return this "typing" attribute.
+    #FIXME: Refactor as follows:
+    #* Iteratively add *ALL* explicitly deeply supported signs to this test.
+    #* Once complete, remove:
+    # if sign is None:
+    #     from beartype._util.data.hint.pep.sign.datapepsignmap import (
+    #         HINT_BARE_NAME_TO_SIGN)
+    #
+    #     #FIXME: This suggests we can probably refactor away a bit of the
+    #     #logic above, thankfully. Namely, we just need to call
+    #     #str.partition('['). There's probably no need to parse the individual
+    #     #"hint_module_name" anymore. *sigh*
+    #     #Namely, we probably just want to do this instead:
+    #     #    hint_bare_name, _, _ = repr(hint).partition('[')
+    #     hint_pep_name = f'{hint_module_name}.{hint_module_attr_name}'
+    #
+    #     # Unsubscripted attribute with this name declared by this module if any
+    #     # *OR* "None" otherwise.
+    #     sign = HINT_BARE_NAME_TO_SIGN.get(hint_pep_name)
+    #
+    #     # If this module declares *NO* such attribute, raise an exception.
+    #     if sign is None:
+    #         raise BeartypeDecorHintPepSignException(
+    #             f'Type hint {repr(hint)} currently unsupported by @beartype. '
+    #             f'Type-checking bear growls in sympathy with your codebase. '
+    #             f'You suddenly feel encouraged to report this to '
+    #             f'the beartype issue tracker at: {URL_ISSUES}'
+    #         )
+    #     # Else, this module declares this attribute.
+
+    # Return this attribute.
     return sign
 
 # ....................{ GETTERS ~ type : generic          }....................
@@ -711,7 +758,7 @@ def get_hint_pep_stdlib_type(hint: object) -> type:
     # If this type does *NOT* exist, raise an exception.
     if hint_type_origin is None:
         raise BeartypeDecorHintPepException(
-            f'PEP type hint {repr(hint)} not originative '
+            f'Type hint {repr(hint)} not originative '
             f'(i.e., does not originate from external class).'
         )
     # Else, this type exists.
@@ -766,7 +813,7 @@ def get_hint_pep_stdlib_type_or_none(hint: Any) -> Optional[type]:
     return (
         # If this sign originates from an origin type, that type.
         _get_hint_pep_origin_object_or_none(hint)
-        if hint_sign in HINT_PEP_SIGNS_TYPE_ORIGIN_STDLIB else
+        if hint_sign in HINT_SIGNS_TYPE_ORIGIN_STDLIB else
         # Else, "None".
         None
     )
@@ -776,7 +823,7 @@ def get_hint_pep_generic_bases_unerased(hint: object) -> Tuple[object, ...]:
     '''
     Tuple of all **unerased pseudo-superclasses** (i.e., PEP-compliant objects
     originally listed as superclasses prior to their implicit type erasure
-    under `PEP 560`_) of the passed PEP-compliant **generic** (i.e., class
+    under :pep:`560`) of the passed PEP-compliant **generic** (i.e., class
     superficially subclassing at least one non-class PEP-compliant object) if
     this object is a generic *or* raise an exception otherwise (i.e., if this
     object is either not a class *or* is a class subclassing no non-class
@@ -806,16 +853,16 @@ def get_hint_pep_generic_bases_unerased(hint: object) -> Tuple[object, ...]:
 
     Motivation
     ----------
-    `PEP 560`_ (i.e., "Core support for typing module and generic types)
+    :pep:`560` (i.e., "Core support for typing module and generic types)
     formalizes the ``__orig_bases__`` dunder attribute first informally
-    introduced by the :mod:`typing` module's implementation of `PEP 484`_.
-    Naturally, `PEP 560`_ remains as unusable as `PEP 484`_ itself. Ideally,
-    `PEP 560`_ would have generalized the core intention of preserving each
+    introduced by the :mod:`typing` module's implementation of :pep:`484`.
+    Naturally, :pep:`560` remains as unusable as :pep:`484` itself. Ideally,
+    :pep:`560` would have generalized the core intention of preserving each
     original user-specified subclass tuple of superclasses as a full-blown
     ``__orig_mro__`` dunder attribute listing the original method resolution
     order (MRO) of that subclass had that tuple *not* been modified.
 
-    Naturally, `PEP 560`_ did no such thing. The original MRO remains
+    Naturally, :pep:`560` did no such thing. The original MRO remains
     obfuscated and effectively inaccessible. While computing that MRO would
     technically be feasible, doing so would also be highly non-trivial,
     expensive, and fragile. Instead, this function retrieves *only* the tuple
@@ -823,15 +870,15 @@ def get_hint_pep_generic_bases_unerased(hint: object) -> Tuple[object, ...]:
     originally attempted (but failed) to subclass.
 
     You are probably now agitatedly cogitating to yourself in the darkness:
-    "But @leycec: what do you mean `PEP 560`_? Wasn't `PEP 560`_ released
-    *after* `PEP 484`_? Surely no public API defined by the Python stdlib would
+    "But @leycec: what do you mean :pep:`560`? Wasn't :pep:`560` released
+    *after* :pep:`484`? Surely no public API defined by the Python stdlib would
     be so malicious as to silently alter the tuple of base classes listed by a
     user-defined subclass?"
 
     As we've established both above and elsewhere throughout the codebase,
-    everything developed for `PEP 484` -- including `PEP 560`_, which derives
-    its entire raison d'etre from `PEP 484`_ -- are fundamentally insane. In
-    this case, `PEP 484`_ is insane by subjecting parametrized :mod:`typing`
+    everything developed for `PEP 484` -- including :pep:`560`, which derives
+    its entire raison d'etre from :pep:`484` -- are fundamentally insane. In
+    this case, :pep:`484` is insane by subjecting parametrized :mod:`typing`
     types employed as base classes to "type erasure," because:
 
          ...it is common practice in languages with generics (e.g. Java,
@@ -861,7 +908,7 @@ def get_hint_pep_generic_bases_unerased(hint: object) -> Tuple[object, ...]:
     Since there exists no counterpart to the :class:`typing.Generic`
     superclass, the :mod:`typing` module preserves that superclass in
     unparametrized form. Naturally, this is useless, as an unparametrized
-    :class:`typing.Generic` superclass conveys no meaningful type annotation.
+    :class:`typing.Generic` superclass conveys no meaningful type information.
     All other superclasses are reduced to their non-:mod:`typing`
     counterparts: e.g.,
 
@@ -883,7 +930,7 @@ def get_hint_pep_generic_bases_unerased(hint: object) -> Tuple[object, ...]:
     the generally useless ``__mro__`` dunder tuple. Note, however, that the
     latter *is* still occasionally useful and thus occasionally returned by
     this getter. For inexplicable reasons, **single-inherited protocols**
-    (i.e., classes directly subclassing *only* the `PEP 544`_-compliant
+    (i.e., classes directly subclassing *only* the :pep:`544`-compliant
     :attr:`typing.Protocol` abstract base class (ABC)) are *not* subject to
     type erasure and thus constitute a notable exception to this heuristic:
 
@@ -894,7 +941,8 @@ def get_hint_pep_generic_bases_unerased(hint: object) -> Tuple[object, ...]:
         >>> UserDefinedProtocol.__mro__
         (__main__.UserDefinedProtocol, typing.Protocol, typing.Generic, object)
         >>> UserDefinedProtocol.__orig_bases__
-        AttributeError: type object 'UserDefinedProtocol' has no attribute '__orig_bases__'
+        AttributeError: type object 'UserDefinedProtocol' has no attribute
+        '__orig_bases__'
 
     Welcome to :mod:`typing` hell, where even :mod:`typing` types lie broken
     and misshapen on the killing floor of overzealous theory-crafting purists.
@@ -936,13 +984,6 @@ def get_hint_pep_generic_bases_unerased(hint: object) -> Tuple[object, ...]:
          collections.abc.Container,
          typing.Generic,
          object)
-
-    .. _PEP 484:
-       https://www.python.org/dev/peps/pep-0484
-    .. _PEP 560:
-       https://www.python.org/dev/peps/pep-0560
-    .. _PEP 585:
-       https://www.python.org/dev/peps/pep-0585
     '''
 
     # Tuple of either...
