@@ -4,7 +4,7 @@
 # See "LICENSE" for further details.
 
 '''
-Package-wide **Python interpreter utilities.**
+Project-wide **Python interpreter** utilities.
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
@@ -16,6 +16,10 @@ from platform import python_implementation
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
 
 # ....................{ TESTERS                           }....................
+#FIXME: Inefficient. Just wrap this in a cached function call instead: e.g.,
+#    @callable_cached
+#    def is_pypy() -> bool:
+#        return python_implementation() == 'PyPy'
 IS_PYPY = python_implementation() == 'PyPy'
 '''
 ``True`` only if the current Python interpreter is PyPy.
