@@ -4,37 +4,52 @@
 # See "LICENSE" for further details.
 
 '''
-Package-wide **Python interpreter version utilities**.
+Project-wide **Python interpreter version utilities**.
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                           }....................
-import sys
+from sys import version_info
 
 # See the "beartype.cave" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
 
 # ....................{ CONSTANTS ~ at least              }....................
-IS_PYTHON_AT_LEAST_4_0 = sys.version_info >= (4, 0)
+IS_PYTHON_AT_LEAST_4_0 = version_info >= (4, 0)
 '''
 ``True`` only if the active Python interpreter targets at least Python 4.0.0.
 '''
 
 
+#FIXME: After dropping Python 3.9 support:
+#* Refactor all code conditionally testing this global to be unconditional.
+#* Remove this global.
+#* Remove all decorators resembling:
+#  @skip_if_python_version_less_than('3.10.0')
+IS_PYTHON_AT_LEAST_3_10 = IS_PYTHON_AT_LEAST_4_0 or version_info >= (3, 10)
+'''
+``True`` only if the active Python interpreter targets at least Python 3.10.0.
+'''
+
+
 #FIXME: After dropping Python 3.8 support:
 #* Refactor all code conditionally testing this global to be unconditional.
 #* Remove this global.
-IS_PYTHON_AT_LEAST_3_9 = IS_PYTHON_AT_LEAST_4_0 or sys.version_info >= (3, 9)
+#* Remove all decorators resembling:
+#  @skip_if_python_version_less_than('3.9.0')
+IS_PYTHON_AT_LEAST_3_9 = IS_PYTHON_AT_LEAST_3_10 or version_info >= (3, 9)
 '''
-``True`` only if the active Python interpreter targets at least Python 3.8.0.
+``True`` only if the active Python interpreter targets at least Python 3.9.0.
 '''
 
 
 #FIXME: After dropping Python 3.7 support:
 #* Refactor all code conditionally testing this global to be unconditional.
 #* Remove this global.
-IS_PYTHON_AT_LEAST_3_8 = IS_PYTHON_AT_LEAST_3_9 or sys.version_info >= (3, 8)
+#* Remove all decorators resembling:
+#  @skip_if_python_version_less_than('3.8.0')
+IS_PYTHON_AT_LEAST_3_8 = IS_PYTHON_AT_LEAST_3_9 or version_info >= (3, 8)
 '''
 ``True`` only if the active Python interpreter targets at least Python 3.8.0.
 '''
@@ -43,7 +58,9 @@ IS_PYTHON_AT_LEAST_3_8 = IS_PYTHON_AT_LEAST_3_9 or sys.version_info >= (3, 8)
 #FIXME: After dropping Python 3.6 support:
 #* Refactor all code conditionally testing this global to be unconditional.
 #* Remove this global.
-IS_PYTHON_AT_LEAST_3_7 = IS_PYTHON_AT_LEAST_3_8 or sys.version_info >= (3, 7)
+#* Remove all decorators resembling:
+#  @skip_if_python_version_less_than('3.7.0')
+IS_PYTHON_AT_LEAST_3_7 = IS_PYTHON_AT_LEAST_3_8 or version_info >= (3, 7)
 '''
 ``True`` only if the active Python interpreter targets at least Python 3.7.0.
 '''
