@@ -4,16 +4,17 @@
 # See "LICENSE" for further details.
 
 '''
-Package-wide **text label utilities** (i.e., callables generating
-human-readable strings describing prominent objects or types, which are then
-typically interpolated into exception messages).
+Project-wide **text label** (i.e., human-readable strings describing prominent
+objects or types, typically interpolated into error messages) utilities.
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                           }....................
-from beartype._util.cls.utilclstest import is_classname_builtin
-from beartype._util.utilobject import get_object_type_name
+from beartype._util.utilobject import (
+    get_object_scopes_name,
+    get_object_type_name,
+)
 from collections.abc import Callable
 
 # See the "beartype.cave" submodule for further commentary.
@@ -37,8 +38,44 @@ def label_callable(func: Callable) -> str:
     '''
     assert callable(func), f'{repr(func)} uncallable.'
 
-    # Create and return this label.
-    return f'{func.__name__}()'
+    # Avoid circular import dependencies.
+    from beartype._util.func.utilfuncarg import get_func_args_len_standard
+    from beartype._util.func.utilfuncfile import get_func_filename_or_none
+    from beartype._util.func.utilfunccodeobj import get_func_codeobj
+    from beartype._util.func.utilfunctest import is_func_lambda
+
+    # If the passed callable is a pure-Python lambda function, that callable
+    # has *NO* unique fully-qualified name. In this case, return a string
+    # uniquely identifying this lambda from various code object metadata.
+    if is_func_lambda(func):
+        # Code object underlying this lambda.
+        func_codeobj = get_func_codeobj(func)
+
+        # Human-readable label describing this lambda.
+        func_label = (
+            f'Lambda function of '
+            f'{get_func_args_len_standard(func_codeobj)} argument(s)'
+        )
+
+        # Absolute filename of the file defining this lambda if this lambda was
+        # defined on-disk *OR* "None" otherwise (i.e., if this lambda was
+        # defined in-memory).
+        func_filename = get_func_filename_or_none(func)
+
+        # If this lambda was defined on-disk, describe the location of this
+        # lambda in that file.
+        if func_filename:
+            func_label += (
+                f' declared on line {func_codeobj.co_firstlineno} of '
+                f'file "{func_filename}"'
+            )
+
+        # Return this label.
+        return func_label
+    # Else, the passed callable is *NOT* a pure-Python lambda function and thus
+    # has a unique fully-qualified name. In this case, simply return that name.
+    else:
+        return f'{get_object_scopes_name(func)}()'
 
 
 def label_callable_decorated(func: Callable) -> str:
@@ -146,12 +183,12 @@ def label_callable_decorated_param_value(
     assert isinstance(param_name, str), f'{repr(param_name)} not string.'
 
     # Avoid circular import dependencies.
-    from beartype._util.text.utiltextrepr import get_object_representation
+    from beartype._util.text.utiltextrepr import represent_object
 
     # Create and return this label.
     return (
         f'{label_callable_decorated(func)} parameter '
-        f'{param_name}={get_object_representation(param_value)}'
+        f'{param_name}={represent_object(param_value)}'
     )
 
 # ....................{ LABELLERS ~ callable : return     }....................
@@ -173,7 +210,7 @@ def label_callable_decorated_return(func: Callable) -> str:
     '''
 
     # Create and return this label.
-    return f'{label_callable_decorated(func)} return '
+    return f'{label_callable_decorated(func)} return'
 
 
 def label_callable_decorated_return_value(
@@ -198,12 +235,12 @@ def label_callable_decorated_return_value(
     '''
 
     # Avoid circular import dependencies.
-    from beartype._util.text.utiltextrepr import get_object_representation
+    from beartype._util.text.utiltextrepr import represent_object
 
     # Create and return this label.
     return (
         f'{label_callable_decorated_return(func)} '
-        f'{get_object_representation(return_value)}'
+        f'{represent_object(return_value)}'
     )
 
 # ....................{ LABELLERS ~ callable : class      }....................
@@ -224,6 +261,7 @@ def label_class(cls: type) -> str:
     assert isinstance(cls, type), f'{repr(cls)} not class.'
 
     # Avoid circular import dependencies.
+    from beartype._util.cls.utilclstest import is_classname_builtin
     from beartype._util.hint.pep.proposal.utilhintpep544 import (
         is_hint_pep544_protocol)
 
@@ -270,3 +308,30 @@ def label_class(cls: type) -> str:
 
     # Return this labelled classname.
     return classname
+
+# ....................{ LABELLERS ~ exception             }....................
+def label_exception(exception: Exception) -> str:
+    '''
+    Human-readable label describing the passed exception.
+
+    Caveats
+    ----------
+    **The label returned by this function does not describe the traceback
+    originating this exception.** To do so, consider calling the standard
+    :func:`traceback.format_exc` function instead.
+
+    Parameters
+    ----------
+    exception : Exception
+        Exception to be labelled.
+
+    Returns
+    ----------
+    str
+        Human-readable label describing this exception.
+    '''
+    assert isinstance(exception, Exception), (
+        f'{repr(exception)} not exception.')
+
+    # Return this exception's label.
+    return f'{exception.__class__.__qualname__}: {str(exception)}'
