@@ -19,7 +19,7 @@ This private submodule is *not* intended for importation by downstream callers.
 # ....................{ IMPORTS                           }....................
 from beartype.roar import BeartypeValeSubscriptionException
 from beartype._util.cache.utilcachecall import callable_cached
-from beartype._util.data.utildatadict import merge_mappings_two
+from beartype._util.kind.utilkinddict import merge_mappings_two
 from beartype._util.func.utilfuncarg import get_func_args_len_standard
 from beartype._util.func.utilfuncscope import CallableScope
 from beartype._util.func.utilfunctest import is_func_python
