@@ -17,7 +17,36 @@ This submodule unit tests the public API of the private
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 from pytest import raises
 
-# ....................{ TESTS                             }....................
+# ....................{ TESTS ~ tester                    }....................
+def test_is_module() -> None:
+    '''
+    Test the :func:`beartype._util.py.utilpymodule.is_module` tester.
+    '''
+
+    # Defer heavyweight imports.
+    from beartype._util.py.utilpymodule import is_module
+
+    # Assert this tester accepts the name of a (possibly unimported) existing
+    # importable module.
+    assert is_module(
+        'beartype_test.a00_unit.data.util.py.data_utilpymodule_good') is True
+
+    # Assert this tester accepts the name of an already imported module.
+    assert is_module(
+        'beartype_test.a00_unit.data.util.py.data_utilpymodule_good') is True
+
+    # Assert this tester rejects the name of a module guaranteed *NOT* to
+    # exist, because we fully control the "beartype_test" package.
+    assert is_module(
+        'beartype_test.a00_unit.data.util.py.data_utilpymodule_nonexistent'
+    ) is False
+
+    # Assert this function raises the expected exception when passed the name
+    # of an existing unimportable module.
+    with raises(ValueError):
+        is_module('beartype_test.a00_unit.data.util.py.data_utilpymodule_bad')
+
+# ....................{ TESTS ~ importer                  }....................
 def test_import_module_attr_pass() -> None:
     '''
     Test successful usage of the
