@@ -17,7 +17,7 @@ from beartype._cave._cavefast import (
     NoneType,
 )
 from beartype._cave._cavemap import NoneTypeOr
-from beartype._util.hint.data.utilhintdata import HINTS_IGNORABLE_SHALLOW
+from beartype._util.data.hint.datahint import HINTS_IGNORABLE_SHALLOW
 from beartype_test.a00_unit.data.hint.pep.data_hintpep import (
     HINTS_PEP_HASHABLE,
     HINTS_PEP_IGNORABLE_DEEP,
