@@ -35,8 +35,13 @@ from beartype._cave._cavefast import (
     RegexMatchType,
     RegexCompiledType,
 )
-from beartype._util.hint.data.pep.proposal.utilhintdatapep484 import (
+from beartype._util.data.hint.pep.proposal.datapep484 import (
     HINT_PEP484_TYPE_FORWARDREF)
+from beartype._util.data.hint.pep.sign.datapepsigns import (
+    HintSignGeneric,
+    HintSignNewType,
+    HintSignTypeVar,
+)
 from beartype._util.py.utilpyversion import (
     IS_PYTHON_3_6,
     IS_PYTHON_AT_LEAST_3_7,
@@ -383,7 +388,7 @@ def add_data(data_module: 'ModuleType') -> None:
         # Generic type variable.
         PepHintMetadata(
             hint=T,
-            pep_sign=TypeVar,
+            pep_sign=HintSignTypeVar,
             #FIXME: Remove after fully supporting type variables.
             is_ignorable=True,
             is_subscripted=False,
@@ -403,7 +408,7 @@ def add_data(data_module: 'ModuleType') -> None:
         # String type variable.
         PepHintMetadata(
             hint=AnyStr,
-            pep_sign=TypeVar,
+            pep_sign=HintSignTypeVar,
             #FIXME: Remove after fully supporting type variables.
             is_ignorable=True,
             is_subscripted=False,
@@ -545,7 +550,7 @@ def add_data(data_module: 'ModuleType') -> None:
         # Generic subclassing a single unsubscripted "typing" type.
         PepHintMetadata(
             hint=Pep484GenericUnsubscriptedSingle,
-            pep_sign=Generic,
+            pep_sign=HintSignGeneric,
             generic_type=Pep484GenericUnsubscriptedSingle,
             is_subscripted=False,
             is_type_typing=False,
@@ -571,7 +576,7 @@ def add_data(data_module: 'ModuleType') -> None:
         # Generic subclassing a single unparametrized "typing" type.
         PepHintMetadata(
             hint=Pep484GenericUntypevaredSingle,
-            pep_sign=Generic,
+            pep_sign=HintSignGeneric,
             generic_type=Pep484GenericUntypevaredSingle,
             is_subscripted=False,
             is_type_typing=False,
@@ -597,7 +602,7 @@ def add_data(data_module: 'ModuleType') -> None:
         # Generic subclassing a single parametrized "typing" type.
         PepHintMetadata(
             hint=Pep484GenericTypevaredSingle,
-            pep_sign=Generic,
+            pep_sign=HintSignGeneric,
             generic_type=Pep484GenericTypevaredSingle,
             is_typevared=True,
             is_type_typing=False,
@@ -618,7 +623,7 @@ def add_data(data_module: 'ModuleType') -> None:
         # parametrized by the same type variables in the same order.
         PepHintMetadata(
             hint=Pep484GenericTypevaredSingle[S, T],
-            pep_sign=Generic,
+            pep_sign=HintSignGeneric,
             generic_type=Pep484GenericTypevaredSingle,
             is_typevared=True,
             # The type of subscripted PEP 484-compliant generics is:
@@ -644,7 +649,7 @@ def add_data(data_module: 'ModuleType') -> None:
         # non-"typing" abstract base class (ABC).
         PepHintMetadata(
             hint=Pep484GenericUntypevaredMultiple,
-            pep_sign=Generic,
+            pep_sign=HintSignGeneric,
             generic_type=Pep484GenericUntypevaredMultiple,
             is_subscripted=False,
             is_type_typing=False,
@@ -669,7 +674,7 @@ def add_data(data_module: 'ModuleType') -> None:
         # Generic subclassing multiple parametrized "typing" types.
         PepHintMetadata(
             hint=Pep484GenericTypevaredShallowMultiple,
-            pep_sign=Generic,
+            pep_sign=HintSignGeneric,
             generic_type=Pep484GenericTypevaredShallowMultiple,
             is_typevared=True,
             is_type_typing=False,
@@ -692,7 +697,7 @@ def add_data(data_module: 'ModuleType') -> None:
         # *AND* a non-"typing" abstract base class (ABC).
         PepHintMetadata(
             hint=Pep484GenericTypevaredDeepMultiple,
-            pep_sign=Generic,
+            pep_sign=HintSignGeneric,
             generic_type=Pep484GenericTypevaredDeepMultiple,
             is_typevared=True,
             is_type_typing=False,
@@ -862,7 +867,7 @@ def add_data(data_module: 'ModuleType') -> None:
         # New type aliasing a non-ignorable type.
         PepHintMetadata(
             hint=NewType('TotallyNotAStr', str),
-            pep_sign=NewType,
+            pep_sign=HintSignNewType,
             is_subscripted=False,
             # New types are merely pure-Python functions of the pure-Python
             # function type, which is *NOT* defined by the "typing" module.
@@ -1662,7 +1667,7 @@ def add_data(data_module: 'ModuleType') -> None:
         data_module.HINTS_PEP_META.extend((
             # ..............{ UNSUBSCRIPTED                     }..............
             # See the
-            # "beartype._util.hint.data.pep.utilhintdatapep.TYPING_ATTR_TO_TYPE_ORIGIN"
+            # "beartype._util.data.hint.pep.datapep.TYPING_ATTR_TO_TYPE_ORIGIN"
             # dictionary for detailed discussion.
 
             # Unsubscripted "Hashable" attribute.
@@ -1720,7 +1725,7 @@ def add_data(data_module: 'ModuleType') -> None:
                 # indistinguishable from PEP 585-compliant type hints.
                 PepHintMetadata(
                     hint=Pep484GenericUnsubscriptedSingle[str],
-                    pep_sign=Generic,
+                    pep_sign=HintSignGeneric,
                     generic_type=Pep484GenericUnsubscriptedSingle,
                     is_type_typing=False,
                     piths_satisfied_meta=(
